@@ -18,14 +18,19 @@ Author(s): Melissa LeBlanc-Williams for Adafruit Industries
 import sys
 import board
 from PIL import Image
-import adafruit_is31fl3731
+
+# uncomment next line if you are using Adafruit 16x9 Charlieplexed PWM LED Matrix
+# from adafruit_is31fl3731.matrix import Matrix as Display
+# uncomment next line if you are using Adafruit 16x8 Charlieplexed Bonnet
+from adafruit_is31fl3731.charlie_bonnet import CharlieBonnet as Display
+
+# uncomment next line if you are using Pimoroni Scroll Phat HD LED 17 x 7
+# from adafruit_is31fl3731.scroll_phat_hd import ScrollPhatHD as Display
 
 i2c = board.I2C()
 
-# uncomment line if you are using Adafruit 16x9 Charlieplexed PWM LED Matrix
-# display = adafruit_is31fl3731.Matrix(i2c)
-# uncomment line if you are using Adafruit 16x9 Charlieplexed PWM LED Matrix
-display = adafruit_is31fl3731.CharlieBonnet(i2c)
+display = Display(i2c)
+
 
 # Open the gif
 if len(sys.argv) < 2:
@@ -52,13 +57,10 @@ else:
     loops = 1
 
 # IS31FL3731 only supports 0-7
-if loops > 7:
-    loops = 7
+loops = min(loops, 7)
 
 # Get the frame count (maximum 8 frames)
-frame_count = image.n_frames
-if frame_count > 8:
-    frame_count = 8
+frame_count = min(image.n_frames, 8)
 
 # Load each frame of the gif onto the Matrix
 for frame in range(frame_count):
